==> fabric-cf-0.11.tar.gz: fabric-cf-0.11/fabric_cf/actor/core/delegation/delegation_factory.py <==
#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)

from fabric_cf.actor.core.util.id import ID
from .delegation import Delegation
from ..apis.i_delegation import IDelegation


class DelegationFactory:
    """
    Factory class to create delegation instances
    """
    @staticmethod
    def create(did: str, slice_id: ID, delegation_name: str = None) -> IDelegation:
        """
        Create a delegation
        @param did delegation id
        @param slice_id slice id
        @param delegation_name delegation_name
        @return delegation
        """
        delegation = Delegation(dlg_graph_id=did, slice_id=slice_id, delegation_name=delegation_name)
        return delegation

==> fabric-cf-1.1.1.tar.gz: fabric-cf-1.1.1/fabric_cf/actor/core/delegation/delegation_factory.py <==
#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)

from fabric_cf.actor.core.util.id import ID
from .delegation import Delegation
from ..apis.abc_delegation import ABCDelegation


class DelegationFactory:
    """
    Factory class to create delegation instances
    """
    @staticmethod
    def create(did: str, slice_id: ID, delegation_name: str = None) -> ABCDelegation:
        """
        Create a delegation
        @param did delegation id
        @param slice_id slice id
        @param delegation_name delegation_name
        @return delegation
        """
        delegation = Delegation(dlg_graph_id=did, slice_id=slice_id, delegation_name=delegation_name)
        return delegation
